@@ -260,6 +260,9 @@ FilePath FileNames::DataDir()
          if (configHome.empty())
          {
             configHome = wxGetenv("HOME") + wxString("/.config/") + wxString(APP_NAME);
+         } else
+         {
+            configHome += wxString("/") + wxString(APP_NAME);
          }
          dataDir = configHome;
 #endif
@@ -707,7 +710,7 @@ wxString FileNames::UnsavedProjectExtension()
 
 // How to detect whether the file system of a path is FAT
 // No apparent way to do it with wxWidgets
-#if defined(__DARWIN__)
+#if defined(__DARWIN__) || defined(__FreeBSD__)
 #include <sys/mount.h>
 bool FileNames::IsOnFATFileSystem(const FilePath &path)
 {
@@ -715,7 +718,12 @@ bool FileNames::IsOnFATFileSystem(const FilePath &path)
    if (statfs(wxPathOnly(path).c_str(), &fs))
       // Error from statfs
       return false;
+
+   #ifdef __FreeBSD__
+   return 0 == strcmp(fs.f_fstypename, "msdosfs");
+   #else
    return 0 == strcmp(fs.f_fstypename, "msdos");
+   #endif
 }
 #elif defined(__linux__)
 #include <sys/statfs.h>
